import { enumDictList, queryLabelList, queryCategoryList, queryAuthList } from "@/services/global"
import { useReducer, useState } from "react"

type State = {
    enumList?: { [key: string]: any },//枚举
    labelList?: any[],//标签列表
    categoryList?: any[],//分类列表
    authList?: any[],//作者列表
}
type Action = {
    params?: any,
    type: 'setEnum' | 'setLabelList' | 'setCategoryList' | 'setAuthList' | "setAll",
}
export function reducer(state: State, action: Action) {
    let { type, params } = action
    switch (type) {
        case 'setEnum':
            return { ...state, enumList: params?.enumList }
        case 'setLabelList':
            return { ...state, labelList: params?.labelList }
        case 'setCategoryList':
            return { ...state, categoryList: params?.categoryList }
        case 'setAuthList':
            return { ...state, authList: params?.authList }
        case 'setAll':
            return { ...state, ...params }
        default:
            return state;
    }
}
export default (): { state: State, init: () => void, getEnum: (enumName: string, type: "map" | "arr" | "obj") => any, getLabelAndClassList: (params?: { workDirection: number | string }) => Promise<boolean> } => {
    const [state, dispatch] = useReducer(reducer, {})
    let isLoding = false
    const init = async () => {
        if (isLoding) {
            return
        }
        console.log("初始化")
        isLoding = true
        let enumData: any = await enumDictList().then((res) => res.data).catch((err) => { console.log(err) })
        let authList = await queryAuthList().then((res) => res.data).catch((err) => { console.log(err) })
        let enumList: { [key: string]: any } = {}
        if (enumData) {
            Object.values(enumData.enums).map((item: any) => {
                enumList[item.name] = item
            })
        }
        // 企业类型美剧
        enumList["SUBJECTTYPE"] = {
            values: [
                { value: 1, description: "企业" },
                { value: 2, description: "政府以及事业单位" },
                { value: 3, description: "其他组织" },
                { value: 4, description: "团队号" }
            ]
        }
        //授权方企业类型
        enumList["CORPTYPE"] = {
            values: [
                { value: "verified", description: "认证号" },
                { value: "unverified", description: "注册号" },
            ]
        }
         //企微通讯录状态
         enumList["CORPSTATE"] = {
            values: [
                { value: 1, description: "已激活" },
                { value: 2, description: "已禁用" },
                { value: 4, description: "未激活" },
                { value: 5, description: "退出企业" },
            ]
        }
        //公众号认证类型
        enumList["VERIFYTYPE"] = {
            values: [
                { value: -1, description: "未认证" },
                { value: 0, description: "微信认证" },
                { value: 1, description: "新浪微博认证" },
                { value: 2, description: "腾讯微博认证" },
                { value: 3, description: "已资质认证通过但还未通过名称认证" },
                { value: 4, description: "已资质认证通过、还未通过名称认证，但通过了新浪微博认证" },
                { value: 5, description: "已资质认证通过、还未通过名称认证，但通过了腾讯微博认证" },
            ]
        }
        dispatch({ type: "setAll", params: { enumList, authList } })
        isLoding = false
    }
    const getLabelAndClassList = async (params?: { workDirection: number | string }) => {
        let labelList = null
        let categoryList = null
        if (typeof params?.workDirection === 'number') {
            labelList = await queryLabelList(params).then((res) => res.data).catch((err) => { console.log(err) })
            categoryList = await queryCategoryList(params).then((res) => res.data).catch((err) => { console.log(err) })
        }
        dispatch({ type: "setAll", params: { ...state, labelList, categoryList } })
        return true
    }
    const getEnum = (enumName: string, type: "map" | "arr" | "obj") => {
        let arr = state?.enumList?.[enumName]?.values
        // console.log("arr",enumName,arr)
        switch (type) {
            case "map":
                return new Map(arr?.map(({ value, description }: any) => [value, description]))
            case "arr":
                return arr?.map(({ value, description }: any) => ({ value, key: value, label: description, disabled: false }))
            case "obj":
                let obj: any = {}
                if (arr) {
                    for (let item of arr) {
                        obj[item?.value] = { text: item?.description, disabled: false }
                    }
                }
                return obj
        }
    }
    return {
        state,
        init,
        getEnum,
        getLabelAndClassList
    }
}