import { useAjax } from "@/Hook/useAjax"
import { getAppAccountConfig, tencentAdAccountDoAuth, tencentAdAccountToAuth } from "@/services/miniApp/adBack"
import { PageContainer, ProCard, ProForm, ProFormRadio, ProFormSelect, ProFormText } from "@ant-design/pro-components"
import { history, useModel } from "@umijs/max"
import { Button, Divider, Space } from "antd"
import { useEffect, useRef, useState } from "react"

function Auth() {
    let { getEnum } = useModel('global')
    let { initialState } = useModel("@@initialState")
    let [key, setKey] = useState<any>()
    let [isEdit, setIsEdit] = useState(false)
    let formRef = useRef()
    let TencentAdAccountToAuth = useAjax((params) => tencentAdAccountToAuth(params))//获取授权地址
    let TencentAdAccountDoAuth = useAjax((params) => tencentAdAccountDoAuth(params))//开始授权
    let GetAppAccountConfig = useAjax((params) => getAppAccountConfig(params))//获取回传配置
    // 获取广告回传列表
    useEffect(() => {
        console.log("history.location.search", history.location.search)
        getConfig()
    }, [])
    //获取回传配置
    const getConfig = () => {
        GetAppAccountConfig.run({ appType: initialState?.selectApp?.appType, appId: initialState?.selectApp?.id })
    }
    // 授权
    const auth = () => {
        TencentAdAccountToAuth.run({
            appType: initialState?.selectApp?.appType,
            appId: initialState?.selectApp?.id,
            advertisingChannel: key,
            callbackPage: "https://testdistribution.zanxiangwl.com/#/miniApp/adBack"
        }).then(res => {
            if (res.code === 200) {
                window.open(res.data)
            }
        })
    }
    return <PageContainer
        tabList={getEnum("ADVERTISING_CHANNEL", "arr")?.map((item: { label: any; key: any }, index: number) => {
            if (index === 0 && !key) {
                setKey(item.key)
            }
            return { tab: item.label, key: item.key }
        })}
        tabProps={{
            type: 'card',
            hideAdd: true,
            onChange: (e) => setKey(e),
        }}
    >
        <ProCard direction="column" ghost gutter={8} >
            <ProCard
                bordered
                title="归因设置"
                actions={
                    <Space style={{ margin: 20 }}> <Button type="primary" onClick={auth}>授权</Button></Space>
                }
            >
                <ProForm
                    readonly={true}
                    submitter={false}
                    colProps={{ span: 2 }}
                    labelCol={{ span: 1 }}
                    layout="horizontal"
                >
                    <ProFormText label={"归因方式"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormText label={"数据源类型"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormText label={"数据源ID"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormText label={"已授权账号ID"} formItemProps={{ style: { marginBottom: 10 } }} />
                </ProForm>

            </ProCard>
            <ProCard
                bordered
                title="回传设置"
                tooltip="回传“下单”“付费”两个行为事件，直投小程序链路额外支持“注册”（纯新+染色回流用户进入小程序）事件回传。"
                actions={<Space style={{ margin: 20 }}>
                    {
                        !isEdit ? <>
                            <Button type="primary" onClick={() => { setIsEdit(true) }}>编辑</Button>
                            <Button>取消回传</Button>
                        </> : <>
                            <Button type="primary" onClick={() => { setIsEdit(true) }}>保存</Button>
                            <Button onClick={() => { setIsEdit(false) }}>取消</Button>
                        </>
                    }
                </Space>}
            >
                <ProForm
                    readonly={!isEdit}
                    formRef={formRef}
                    submitter={false}
                    colProps={{ span: 2 }}
                    labelCol={{ span: 1 }}
                    layout="horizontal"
                >
                    <ProFormText label={"投放场景"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormRadio.Group label={"回传口径"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormSelect label={"回传用户"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormRadio.Group label={"部分回传"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormRadio.Group label={"ROI 投放"} formItemProps={{ style: { marginBottom: 10 } }} />
                </ProForm>
            </ProCard>
        </ProCard>
    </PageContainer>
}

export default Auth